@@ -1,6 +1,10 @@
+from utils.Dict import Dict
 from utils.File import CSVFile, File, JSONFile, TSVFile, XSVFile, Zip
 from utils.Git import Git
 from utils.GoogleMaps import GoogleMaps
+from utils.List import List
+from utils.RandomColor import RandomColor
+from utils.Table import Table, TableRow
 from utils.Time import (AVG_DAYS_IN, SECONDS_IN, TIMEZONE_OFFSET, Time,
                         TimeDelta, TimeFormat)
 from utils.www import WWW
